cmd

package
v0.0.0-...-f34c3c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 18, 2017 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ServerIP contains the IP address the server listens on.
	ServerIP string

	// ServerPort contains the port used by the server.
	ServerPort string

	// DBCommand contains the db command to be executed on server start.
	DBCommand string
)

Functions

func ConfigSetup

func ConfigSetup()

ConfigSetup sets up Viper for easier configuration management.

func FlagArguments

func FlagArguments()

FlagArguments parses the command line flag arguments provided to the executable.

Types

This section is empty.

Directories

Path Synopsis

Jump to